@@ -84,7 +84,7 @@ ActionReply PlymouthHelper::save(const QVariantMap &args)
     }
 
     {
-        KConfigGroup cg(KSharedConfig::openConfig(QStringLiteral(PLYMOUTH_CONFIG_PATH)), "Daemon");
+        KConfigGroup cg(KSharedConfig::openConfig(QStringLiteral(PLYMOUTH_CONFIG_PATH)), QStringLiteral("Daemon"));
         cg.writeEntry("Theme", theme);
     }
     QFile configFile(QStringLiteral(PLYMOUTH_CONFIG_PATH));
@@ -154,12 +154,23 @@ ActionReply PlymouthHelper::save(const QVariantMap &args)
     }
 
     QProcess process;
-    qDebug() << "Running update-initramfs -u  now";
-    process.start(QStringLiteral("/usr/sbin/update-initramfs"), QStringList() << QStringLiteral("-u"));
-    if (!process.waitForStarted()) {
-        reply = ActionReply::BackendError;
-        reply.setErrorDescription(i18n("Cannot start initramfs."));
-        return reply;
+    if (QFileInfo::exists(QStringLiteral("/usr/sbin/update-initramfs"))) {
+        qDebug() << "Running update-initramfs -u now";
+        process.start(QStringLiteral("/usr/sbin/update-initramfs"), QStringList() << QStringLiteral("-u"));
+        if (!process.waitForStarted()) {
+            reply = ActionReply::BackendError;
+            reply.setErrorDescription(i18n("Cannot start initramfs."));
+            return reply;
+        }
+    }
+    if (QFileInfo::exists(QStringLiteral("/usr/bin/mkinitcpio"))) {
+        qDebug() << "Running mkinitcpio -P now";
+        process.start(QStringLiteral("/usr/bin/mkinitcpio"), QStringList() << QStringLiteral("-P"));
+        if (!process.waitForStarted()) {
+            reply = ActionReply::BackendError;
+            reply.setErrorDescription(i18n("Cannot start mkinitcpio."));
+            return reply;
+        }
     }
     // We don't know how long this will take. The helper will need to generate N=installed_kernels initrds.
     // Be very generous with the timeout! https://bugs.kde.org/show_bug.cgi?id=400641
@@ -204,7 +215,7 @@ ActionReply PlymouthHelper::install(const QVariantMap &args)
     // FIXME: KArchive should provide "safe mode" for this!
     QScopedPointer<KArchive> archive;
 
-    static QVector<QString> tarTypes = {
+    static QList<QString> tarTypes = {
         QStringLiteral("application/tar"),
         QStringLiteral("application/x-gzip"),
         QStringLiteral("application/x-bzip"),
@@ -245,8 +256,6 @@ ActionReply PlymouthHelper::install(const QVariantMap &args)
     }
     dir->copyTo(installpath);
 
-    const QStringList themeFileList = dir->entries().filter(QRegularExpression(QStringLiteral("\\.plymouth$")));
-
     archive->close();
 
     // Special case: Ubuntu derivatives, which work different from everybody else
@@ -337,3 +346,5 @@ ActionReply PlymouthHelper::uninstall(const QVariantMap &args)
 }
 
 KAUTH_HELPER_MAIN("org.kde.kcontrol.kcmplymouth", PlymouthHelper)
+
+#include "moc_helper.cpp"
